<?php

namespace ADELANTE\PayBySquare\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\Encryption\EncryptorInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 * Class Data
 *
 * @package ADELANTE\PayBySquare\Helper
 */
class Data extends AbstractHelper
{

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * @var EncryptorInterface
     */
    private $encryptor;

    /**
     * Data constructor.
     *
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param EncryptorInterface $encryptor
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        EncryptorInterface $encryptor
    ) {
        parent::__construct($context);
        $this->_storeManager  = $storeManager;
        $this->encryptor = $encryptor;
    }

    /**
     * @return bool
     */
    public function isEnableConfig(): bool
    {
        return (bool)$this->scopeConfig->getValue('pay_by_square/general/enable', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getUsername(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/username', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getPassword(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/password', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getBeneficaryName(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/beneficary_name', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return array
     */
    public function getBankAccounts(): array
    {
        $out = [];
        $accounts = (string)$this->scopeConfig->getValue('pay_by_square/general/bank_accounts', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
        $bics = (string)$this->scopeConfig->getValue('pay_by_square/general/bank_accounts_bics', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
        $accounts = explode("\n", $accounts);
        $bics = explode("\n", $bics);
        foreach ($accounts as $key => $account) {
            $out[] = [
                'account' => str_replace(' ', '', $account),
                'bic' => $bics[$key] ?? null
            ];
        }
        return $out;
    }

    /**
     * @return string
     */
    public function getNote(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/note', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }
}
